@@ -3,6 +3,7 @@ import logging
 from .__version__ import __author__, __version__
 from .api import connect, consume, disconnect, get, publish, publish_all
 from .config import configure
+from .message import Message, Packet
 from .session import AmqpSession
 
 __all__ = [
@@ -16,6 +17,8 @@ __all__ = [
     "connect",
     "disconnect",
     "AmqpSession",
+    "Packet",
+    "Message",
 ]
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
