@@ -12,6 +12,8 @@ from typing import Union, List, Dict, Any
 
 import pika
 
+from .exceptions import EncodingError
+
 JSONType = Union[str, int, float, bool, None, Dict[str, Any], List[Any]]
 
 
@@ -19,8 +21,13 @@ class Message:
     def __init__(self, message: Any) -> None:
         self._message = message
 
-    def encode(self) -> str:
-        return json.dumps(self._message)
+    def encode(self) -> bytes:
+        if isinstance(self._message, bytes):
+            return self._message
+        try:
+            return bytes(json.dumps(self._message), encoding='utf-8')
+        except (TypeError, ValueError):
+            raise EncodingError(f"Could not encode the message {self._message}")
 
     def decode(self) -> Any:
         return json.loads(self._message)
@@ -28,6 +35,9 @@ class Message:
     def __str__(self) -> str:
         return f"Message: {self._message}"
 
+    def __repr__(self) -> str:
+        return f'<Message: {self._message}>'
+
 
 @dataclass
 class Packet:
