@@ -2,7 +2,7 @@ import pytest
 
 import quickmq
 from quickmq.exceptions import NotConnectedError
-from quickmq.session import get_current_session, AmqpSession, exit_handler
+from quickmq.session import AmqpSession
 
 
 def test_context_manager():
@@ -30,9 +30,9 @@ def test_connect_context_manager():
 
 
 def test_auto_connect():
-    quickmq.publish("hello")
-    assert len(get_current_session().pool.connections) == 1
-    quickmq.disconnect()
+    with AmqpSession() as session:
+        session.publish('hello')
+        assert len(session.servers) == 1
 
 
 def test_cannot_connect_default():
@@ -43,20 +43,14 @@ def test_cannot_connect_default():
 
 
 def test_disconnect_args():
-    quickmq.connect("localhost")
-    assert len(get_current_session().pool.connections) == 1
-    quickmq.disconnect("localhost")
-    assert len(get_current_session().pool.connections) == 0
+    session = AmqpSession()
+    session.connect('localhost')
+    assert len(session.pool.connections) == 1
+    session.disconnect("localhost")
+    assert len(session.pool.connections) == 0
 
 
 def test_deletion():
     new_session = AmqpSession()
     new_session.connect("localhost")
     del new_session
-
-
-def test_auto_disconnect():
-    quickmq.connect("localhost")
-    assert len(get_current_session().servers) == 1
-    exit_handler()
-    assert len(get_current_session().servers) == 0
